@@ -1,5 +1,12 @@
 # ptah api
 
+try:
+    from collections import OrderedDict
+except ImportError: # pragma: no cover
+    import collections
+    from ordereddict import OrderedDict
+    collections.OrderedDict = OrderedDict
+
 # config
 from ptah import config
 from ptah.config import adapter
