@@ -1,21 +1,18 @@
 import transaction
-import ptah
 import sqlalchemy as sqla
 from webob.multidict import MultiDict
 from pyramid.testing import DummyRequest
+from pyramid.compat import url_quote_plus
 from pyramid.httpexceptions import HTTPFound
+from pyramid.view import render_view_to_response
 
-from base import Base
+import ptah
+from ptah.testing import PtahTestCase
+
+Session = ptah.get_session()
 
 
-class TestSqlaModuleContent(ptah.cms.Content):
-
-    __tablename__ = 'test_sqla_content'
-    __type__ = ptah.cms.Type('Test')
-    name = sqla.Column(sqla.Unicode())
-
-
-class TestSqlaModuleTable(ptah.cms.Base):
+class TestSqlaModuleTable(ptah.get_base()):
 
     __tablename__ = 'test_sqla_table'
 
@@ -23,20 +20,25 @@ class TestSqlaModuleTable(ptah.cms.Base):
     name = sqla.Column(sqla.Unicode())
 
 
+class TestSqlaModule(PtahTestCase):
 
-class TestSqlaModule(Base):
-
-    def tearDown(self):
-        ptah.config.cleanup_system(self.__class__.__module__)
-        super(TestSqlaModule, self).tearDown()
+    def setUp(self):
+        global TestSqlaModuleContent
+        class TestSqlaModuleContent(ptah.cms.Content):
+            __tablename__ = 'test_sqla_content'
+            __table_args__ = {'extend_existing': True}
+            __type__ = ptah.cms.Type('Test')
+            name = sqla.Column(sqla.Unicode())
+        super(TestSqlaModule, self).setUp()
 
     def test_sqla_module(self):
-        from ptah.manage.manage import CONFIG, PtahManageRoute
+        from ptah.manage.manage import PtahManageRoute
         from ptah.manage.sqla import SQLAModule, Table
 
         request = DummyRequest()
 
-        CONFIG['managers'] = ['*']
+        cfg = ptah.get_settings(ptah.CFG_ID_PTAH, self.registry)
+        cfg['managers'] = ['*']
         mr = PtahManageRoute(request)
         mod = mr['sqla']
         self.assertIsInstance(mod, SQLAModule)
@@ -66,7 +68,7 @@ class TestSqlaModule(Base):
 
         mod = SQLAModule(None, request)
 
-        res = MainView.__renderer__(mod, request)
+        res = render_view_to_response(mod, request, '', False)
         self.assertEqual(res.status, '200 OK')
 
     def test_sqla_table_view(self):
@@ -77,21 +79,21 @@ class TestSqlaModule(Base):
         mod = SQLAModule(None, request)
         table = mod['psqla-ptah_tokens']
 
-        res = TableView.__renderer__(table, request)
+        res = render_view_to_response(table, request, '', False)
         self.assertEqual(res.status, '200 OK')
-        self.assertIn('form.buttons.add', res.body)
+        self.assertIn('form.buttons.add', res.text)
 
     def test_sqla_table_view_model(self):
         from ptah.manage.sqla import SQLAModule, TableView
 
-        ptah.cms.Session.add(TestSqlaModuleContent(title='test'))
+        Session.add(TestSqlaModuleContent(title='test'))
 
         request = DummyRequest()
 
         mod = SQLAModule(None, request)
         table = mod['psqla-test_sqla_content']
 
-        res = TableView.__renderer__(table, request).body
+        res = render_view_to_response(table, request, '', False).text
         self.assertIn('Inherits from:', res)
         self.assertIn('ptah_node', res)
         self.assertIn('ptah_content', res)
@@ -101,8 +103,8 @@ class TestSqlaModule(Base):
         from ptah.manage.sqla import SQLAModule, TableView
 
         rec = TestSqlaModuleContent(title='test')
-        ptah.cms.Session.add(rec)
-        ptah.cms.Session.flush()
+        Session.add(rec)
+        Session.flush()
 
         uri = rec.__uri__
         type_uri = rec.__type__.__uri__
@@ -112,17 +114,17 @@ class TestSqlaModule(Base):
         mod = SQLAModule(None, request)
         table = mod['psqla-ptah_nodes']
 
-        res = TableView.__renderer__(table, request).body
-        self.assertIn(uri, res)
-        self.assertIn(type_uri, res)
+        res = render_view_to_response(table, request, '', False).text
+        self.assertIn(url_quote_plus(uri), res)
+        self.assertIn(url_quote_plus(type_uri), res)
 
         request = DummyRequest(params={'batch': 'unknown'})
-        res = TableView.__renderer__(table, request).body
-        self.assertIn(uri, res)
+        res = render_view_to_response(table, request, '', False).text
+        self.assertIn(url_quote_plus(uri), res)
 
         request = DummyRequest(params={'batch': '0'})
-        res = TableView.__renderer__(table, request).body
-        self.assertIn(uri, res)
+        res = render_view_to_response(table, request, '', False).text
+        self.assertIn(url_quote_plus(uri), res)
 
     def test_sqla_table_view_inheritance(self):
         from ptah.manage.sqla import SQLAModule, TableView
@@ -132,27 +134,24 @@ class TestSqlaModule(Base):
         mod = SQLAModule(None, request)
         table = mod['psqla-ptah_tokens']
 
-        res = TableView.__renderer__(table, request)
+        res = render_view_to_response(table, request, '', False)
         self.assertEqual(res.status, '200 OK')
 
     def test_sqla_table_traverse(self):
         from ptah.manage.sqla import SQLAModule, Record
+        from ptah.settings import SettingRecord
 
-        from ptah import token
-        from ptah.util import CSRFService
+        inst = SettingRecord(name='test', value='12345')
+        Session.add(inst)
+        Session.flush()
 
-        tid = token.service.generate(CSRFService.TOKEN_TYPE, 'test')
-        inst = token.service._sql_get.first(token=tid)
+        mod = SQLAModule(None, DummyRequest())
+        table = mod['psqla-ptah_settings']
 
-        request = DummyRequest()
-
-        mod = SQLAModule(None, request)
-        table = mod['psqla-ptah_tokens']
-
-        rec = table[str(inst.id)]
+        rec = table[str(inst.name)]
 
         self.assertIsInstance(rec, Record)
-        self.assertEqual(rec.pname, 'id')
+        self.assertEqual(rec.pname, 'name')
         self.assertIsNotNone(rec.pcolumn)
         self.assertIsNotNone(rec.data)
 
@@ -176,10 +175,7 @@ class TestSqlaModule(Base):
             POST={'form.buttons.back': 'Back'})
 
         form = AddRecord(table, request)
-        try:
-            form.update()
-        except Exception, res:
-            pass
+        res = form.update()
 
         self.assertIsInstance(res, HTTPFound)
         self.assertEqual(res.headers['location'], '.')
@@ -193,7 +189,6 @@ class TestSqlaModule(Base):
         table = mod['psqla-test_sqla_table']
 
         request = DummyRequest(
-            session = {},
             POST={'form.buttons.create': 'Create'})
 
         form = AddRecord(table, request)
@@ -201,25 +196,21 @@ class TestSqlaModule(Base):
         form.update()
 
         self.assertIn('Please fix indicated errors',
-                      request.session['msgservice'][0])
+                      ptah.view.render_messages(request))
 
         request = DummyRequest(
-            session = {},
             POST={'form.buttons.create': 'Create',
                   'name': 'Test'})
 
         form = AddRecord(table, request)
         form.csrf = False
-        try:
-            form.update()
-        except Exception, res:
-            pass
+        res = form.update()
 
         self.assertIn('Table record has been created.',
-                      request.session['msgservice'][0])
+                      ptah.view.render_messages(request))
         self.assertIsInstance(res, HTTPFound)
 
-        rec = ptah.cms.Session.query(TestSqlaModuleTable).first()
+        rec = Session.query(TestSqlaModuleTable).first()
         self.assertEqual(rec.name, 'Test')
 
     def test_sqla_table_addrec_create_multi(self):
@@ -231,7 +222,6 @@ class TestSqlaModule(Base):
         table = mod['psqla-test_sqla_table']
 
         request = DummyRequest(
-            session = {},
             POST={'form.buttons.createmulti': 'Create'})
 
         form = AddRecord(table, request)
@@ -239,10 +229,9 @@ class TestSqlaModule(Base):
         form.update()
 
         self.assertIn('Please fix indicated errors',
-                      request.session['msgservice'][0])
+                      ptah.view.render_messages(request))
 
         request = DummyRequest(
-            session = {},
             POST={'form.buttons.createmulti': 'Create',
                   'name': 'Test multi'})
 
@@ -251,9 +240,9 @@ class TestSqlaModule(Base):
         form.update()
 
         self.assertIn('Table record has been created.',
-                      request.session['msgservice'][0])
+                      ptah.view.render_messages(request))
 
-        rec = ptah.cms.Session.query(TestSqlaModuleTable).first()
+        rec = Session.query(TestSqlaModuleTable).first()
         self.assertEqual(rec.name, 'Test multi')
 
     def test_sqla_table_editrec_basics(self):
@@ -261,8 +250,8 @@ class TestSqlaModule(Base):
 
         rec = TestSqlaModuleTable()
         rec.name = 'Test record'
-        ptah.cms.Session.add(rec)
-        ptah.cms.Session.flush()
+        Session.add(rec)
+        Session.flush()
 
         rec_id = rec.id
 
@@ -284,10 +273,7 @@ class TestSqlaModule(Base):
             POST={'form.buttons.cancel': 'Cancel'})
 
         form = EditRecord(rec, request)
-        try:
-            form.update()
-        except Exception, res:
-            pass
+        res = form.update()
 
         self.assertIsInstance(res, HTTPFound)
         self.assertEqual(res.headers['location'], '..')
@@ -297,8 +283,8 @@ class TestSqlaModule(Base):
 
         rec = TestSqlaModuleTable()
         rec.name = 'Test record'
-        ptah.cms.Session.add(rec)
-        ptah.cms.Session.flush()
+        Session.add(rec)
+        Session.flush()
 
         rec_id = rec.id
 
@@ -315,26 +301,22 @@ class TestSqlaModule(Base):
         form.update()
 
         self.assertIn('Please fix indicated errors',
-                      request.session['msgservice'][0])
+                      ptah.view.render_messages(request))
 
         request = DummyRequest(
-            session = {},
             POST={'form.buttons.modify': 'Modify',
                   'name': 'Record modified'})
 
         form = EditRecord(rec, request)
         form.csrf = False
-        try:
-            form.update()
-        except Exception, res:
-            pass
+        res = form.update()
 
         self.assertIn('Table record has been modified.',
-                      request.session['msgservice'][0])
+                      ptah.view.render_messages(request))
         self.assertIsInstance(res, HTTPFound)
         self.assertEqual(res.headers['location'], '..')
 
-        rec = ptah.cms.Session.query(TestSqlaModuleTable).filter(
+        rec = Session.query(TestSqlaModuleTable).filter(
             TestSqlaModuleTable.id == rec_id).first()
         self.assertEqual(rec.name, 'Record modified')
 
@@ -343,8 +325,8 @@ class TestSqlaModule(Base):
 
         rec = TestSqlaModuleTable()
         rec.name = 'Test record'
-        ptah.cms.Session.add(rec)
-        ptah.cms.Session.flush()
+        Session.add(rec)
+        Session.flush()
 
         rec_id = rec.id
 
@@ -358,17 +340,14 @@ class TestSqlaModule(Base):
 
         form = EditRecord(rec, request)
         form.csrf = False
-        try:
-            form.update()
-        except Exception, res:
-            pass
+        res = form.update()
 
         self.assertIn('Table record has been removed.',
-                      request.session['msgservice'][0])
+                      ptah.view.render_messages(request))
         self.assertIsInstance(res, HTTPFound)
         self.assertEqual(res.headers['location'], '..')
 
-        rec = ptah.cms.Session.query(TestSqlaModuleTable).filter(
+        rec = Session.query(TestSqlaModuleTable).filter(
             TestSqlaModuleTable.id == rec_id).first()
         self.assertIsNone(rec, None)
 
@@ -382,10 +361,7 @@ class TestSqlaModule(Base):
             POST={'form.buttons.add': 'Add'})
 
         form = TableView(table, request)
-        try:
-            form.update()
-        except Exception, res:
-            pass
+        res = form.update()
 
         self.assertIsInstance(res, HTTPFound)
         self.assertEqual(res.headers['location'], 'add.html')
@@ -395,8 +371,8 @@ class TestSqlaModule(Base):
 
         rec = TestSqlaModuleTable()
         rec.name = 'Test record'
-        ptah.cms.Session.add(rec)
-        ptah.cms.Session.flush()
+        Session.add(rec)
+        Session.flush()
 
         rec_id = rec.id
 
@@ -404,38 +380,40 @@ class TestSqlaModule(Base):
         table = mod['psqla-test_sqla_table']
 
         request = DummyRequest(
-            POST=MultiDict({'form.buttons.remove': 'Remove'}))
+            POST=MultiDict([('form.buttons.remove', 'Remove')]))
 
         form = TableView(table, request)
         form.csrf = False
         form.update()
 
         self.assertIn('lease select records for removing.',
-                      request.session['msgservice'][0])
+                      ptah.view.render_messages(request))
 
         request = DummyRequest(
-            POST=MultiDict({'form.buttons.remove': 'Remove',
-                            'rowid': 'wrong'}))
+            POST=MultiDict([('form.buttons.remove', 'Remove'),
+                            ('rowid', 'wrong')]))
 
         form = TableView(table, request)
         form.csrf = False
         form.update()
 
-        self.assertIn('lease select records for removing.',
-                      request.session['msgservice'][0])
+        #self.assertIn('Please select records for removing.',
+        #              ptah.view.render_messages(request))
 
         request = DummyRequest(
-            POST=MultiDict({'form.buttons.remove': 'Remove',
-                            'rowid': rec_id}))
+            POST=MultiDict([('form.buttons.remove', 'Remove'),
+                            ('rowid', rec_id),
+                            ('csrf-token',
+                             self.request.session.get_csrf_token())]))
 
         form = TableView(table, request)
-        form.csrf = False
+        form.csrf = True
         form.update()
 
         self.assertIn('Select records have been removed.',
-                      request.session['msgservice'][0])
+                      ptah.view.render_messages(request))
 
-        rec = ptah.cms.Session.query(TestSqlaModuleTable).filter(
+        rec = Session.query(TestSqlaModuleTable).filter(
             TestSqlaModuleTable.id == rec_id).first()
         self.assertIsNone(rec, None)
 
@@ -444,8 +422,8 @@ class TestSqlaModule(Base):
 
         rec = TestSqlaModuleContent()
         rec.name = 'Test record'
-        ptah.cms.Session.add(rec)
-        ptah.cms.Session.flush()
+        Session.add(rec)
+        Session.flush()
 
         rec_id = rec.__id__
 
